@@ -29,6 +29,9 @@ class SearchWidget(Widget):
 class IntWidget(Widget):
     pass
 
+class BoolWidget(Widget):
+    pass
+
 class StringWidget(Widget):
     placeholder: Optional[str]
     pass
@@ -48,4 +51,4 @@ class SliderWidget(Widget):
     max: Optional[int]
 
 
-AllWidgets = Union[SearchWidget, IntWidget, SliderWidget, QueryWidget, ValueWidget, StringWidget]
\ No newline at end of file
+AllWidgets = Union[SearchWidget, IntWidget, SliderWidget, QueryWidget, ValueWidget, StringWidget, BoolWidget]
\ No newline at end of file
